@@ -1,5 +1,7 @@
 from rest_framework import routers
 
+from django.urls import path
+
 from bcmr import views
 
 
@@ -10,4 +12,6 @@ router = routers.DefaultRouter()
 router.register("registries", views.RegistryViewSet)
 router.register("tokens", views.TokenViewSet)
 
-urlpatterns = router.urls
+urlpatterns = router.urls + [
+    path('create_token/fungible/', views.create_fungible_token),
+]
