@@ -1,4 +1,5 @@
 from django.core.exceptions import ImproperlyConfigured
+from django.views.decorators.csrf import csrf_protect
 from django.utils import timezone
 from django.conf import settings
 from django.shortcuts import render
@@ -98,8 +99,9 @@ class RegistryViewSet(viewsets.ModelViewSet):
             return self.serializer_classes[self.action]
         return super().get_serializer_class()
 
- 
-def add_token(request):
+
+@csrf_protect
+def create_fungible_token(request):
     submitted = False
     message = ''
     owner = ''
